@@ -4,18 +4,14 @@
 # Date Started: 20230209                                                                                               #
 ########################################################################################################################
 
-print("this is my init file")
-
+#########################
+# Importing other code  #
+#########################
 from .API_Call import API
-import  atr
-
-
-
-
-
-
+from  .atr import *
+from .util import *
+from .setup import * 
 
 
 
 # End of File
-#
